/***************************************************************************
                         cssprfile.h  -  description
                            -------------------
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSSPRFILE_H
#define CSSPRFILE_H

#include <Plugins/fileplugin.h>

/**
  *@author Rene Dudfield
  */

class CSSPRFile : public FilePlugin
{
   public:
      CSSPRFile();
      ~CSSPRFile();

      void importData( ifstream & );
      void exportData( ofstream & );
      void writeSprite( Object *o, ofstream &out );

      // protected:

}

;


#endif
